NXSConfigServer Tango Class User‘s Guide

## NXSConfigServer Tango Python Class

Contents :

- Description
- Properties
- Commands
  - State
  - Status
  - Open
  - Close
  - Components
  - Selections
  - InstantiatedComponents
  - DataSources
  - AvailableComponents
  - AvailableSelections
  - AvailableDataSources
  - StoreSelection
  - StoreComponent
  - StoreDataSource
  - CreateConfiguration
  - DeleteComponent
  - DeleteSelection
  - DeleteDataSource
  - SetComponentDataSources
  - SetMandatoryComponents
  - MandatoryComponents
  - UnsetMandatoryComponents
  - ComponentDataSources
  - ComponentsDataSources
  - ComponentsVariables
  - ComponentVariables
  - Merge
  - DependentComponents
  - InstantiatedDataSources
- Attributes
  - XMLString
  - Selection
  - JSONSettings
  - Version
  - Variables
  - STEPDataSources
  - LinkDataSources
  - CanFailDataSources
  - ExtraLinkDataSources
  - MergedXML
- States

NXSConfigServer Class Identification : | NXSConfigServer Class Inheritance :
Contact | : at desy.de - jan.kotanski
Class Family | : Acquisition
Platform | : All Platforms
Bus | : Not Applicable
Manufacturer | : DESY
Manufacturer ref. | :
| Tango::DeviceImpl NXSConfigServer

NXSConfigServer Class Description :

NeXuS Configuration Server is a Tango Server with its implementation based
on a MySQL database. It allows to store XML configuration datasources
and components. It also gives possibility to select mandatory components
and perform the process of component merging.
Source code: https://github.com/nexdatas/nxsconfigserver/
Web page: https://nexdatas.github.io/nxsconfigserver/
NexDaTaS Web page: https://nexdatas.github.io

NXSConfigServer Properties :
There is no class properties

Device Properties
Name | Description | Type | Default Value
VersionLabel | version label | String | "XCS"
ExtraLinkPath | extra link path below NXentry, default: instrument:NXinstrument/collection:NXcollection | String | "instrument:NXinstrument/collection:NXcollection"

NXSConfigServer Class Commands
Name | Input type | Output type | Level | Description
State | DEV_VOID | DEV_STATE | OPERATOR | This command gets the device state (stored in its device_state data member) and returns it to the caller.
Status | DEV_VOID | CONST_DEV_STRING | OPERATOR | This command gets the device status (stored in its device_status data member) and returns it to the caller.
Open | DEV_VOID | DEV_VOID | OPERATOR | Opens connection to the database
Close | DEV_VOID | DEV_VOID | OPERATOR | Closes connection into the database
Components | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required components
Selections | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required selections
InstantiatedComponents | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required components
DataSources | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required DataSources
AvailableComponents | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of available component names
AvailableSelections | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of available selection names
AvailableDataSources | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of available DataSource names
StoreSelection | DEV_STRING | DEV_VOID | OPERATOR | Stores the selection from XMLString
StoreComponent | DEV_STRING | DEV_VOID | OPERATOR | Stores the component from XMLString
StoreDataSource | DEV_STRING | DEV_VOID | OPERATOR | Stores the DataSource from XMLString
CreateConfiguration | DEVVAR_STRINGARRAY | DEV_VOID | OPERATOR | Creates the NDTS configuration script from the given components. The result is strored in XMLString
DeleteComponent | DEV_STRING | DEV_VOID | OPERATOR | Deletes the given component
DeleteSelection | DEV_STRING | DEV_VOID | OPERATOR | Deletes the given selection
DeleteDataSource | DEV_STRING | DEV_VOID | OPERATOR | Deletes the given datasource
SetComponentDataSources | DEV_STRING | DEV_VOID | OPERATOR | Sets component datasources according to given dictionary
SetMandatoryComponents | DEVVAR_STRINGARRAY | DEV_VOID | OPERATOR | Sets the mandatory components
MandatoryComponents | DEV_VOID | DEVVAR_STRINGARRAY | OPERATOR | Returns the mandatory components
UnsetMandatoryComponents | DEVVAR_STRINGARRAY | DEV_VOID | OPERATOR | Removes the given components from the mandatory components
ComponentDataSources | DEV_STRING | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of datasource names for a given component
ComponentsDataSources | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of datasource names for a given components
ComponentsVariables | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of variable names for a given components
ComponentVariables | DEV_STRING | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of variable names for a given component
Merge | DEVVAR_STRINGARRAY | DEV_STRING | OPERATOR | Merges give components
DependentComponents | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of dependent component names for a given components
InstantiatedDataSources | DEVVAR_STRINGARRAY | DEVVAR_STRINGARRAY | OPERATOR | Returns a list of required datasources

Command State :

This command gets the device state (stored in its device_state data member) and returns it to the caller.

State Definition
Input Argument | Tango::DEV_VOID | none
Output Argument | Tango::DEV_STATE | Device state
DisplayLevel | OPERATOR | ..
Inherited | true | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command allowed for | All states | ..

Command Status :

This command gets the device status (stored in its device_status data member) and returns it to the caller.

Status Definition
Input Argument | Tango::DEV_VOID | none
Output Argument | Tango::CONST_DEV_STRING | Device status
DisplayLevel | OPERATOR | ..
Inherited | true | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command allowed for | All states | ..

Command Open :

Opens connection to the database

Open Definition
Input Argument | Tango::DEV_VOID |
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | RUNNING | ..

Command Close :

Closes connection into the database

Close Definition
Input Argument | Tango::DEV_VOID |
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command Components :

Returns a list of required components

Components Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of required components
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command Selections :

Returns a list of required selections

Selections Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of selection names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of required selections
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command InstantiatedComponents :

Returns a list of required components

InstantiatedComponents Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of instantiated components
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command DataSources :

Returns a list of required DataSources

DataSources Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of DataSource names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of required DataSources
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command AvailableComponents :

Returns a list of available component names

AvailableComponents Definition
Input Argument | Tango::DEV_VOID |
Output Argument | Tango::DEVVAR_STRINGARRAY | list of available component names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command AvailableSelections :

Returns a list of available selection names

AvailableSelections Definition
Input Argument | Tango::DEV_VOID |
Output Argument | Tango::DEVVAR_STRINGARRAY | list of available selection names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command AvailableDataSources :

Returns a list of available DataSource names

AvailableDataSources Definition
Input Argument | Tango::DEV_VOID |
Output Argument | Tango::DEVVAR_STRINGARRAY | list of available DataSource names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command StoreSelection :

Stores the selection from XMLString

StoreSelection Definition
Input Argument | Tango::DEV_STRING | selection name
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command StoreComponent :

Stores the component from XMLString

StoreComponent Definition
Input Argument | Tango::DEV_STRING | component name
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command StoreDataSource :

Stores the DataSource from XMLString

StoreDataSource Definition
Input Argument | Tango::DEV_STRING | datasource name
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command CreateConfiguration :

Creates the NDTS configuration script from the given components. The result is strored in XMLString

CreateConfiguration Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of component names
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command DeleteComponent :

Deletes the given component

DeleteComponent Definition
Input Argument | Tango::DEV_STRING | component name
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command DeleteSelection :

Deletes the given selection

DeleteSelection Definition
Input Argument | Tango::DEV_STRING | selection name
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command DeleteDataSource :

Deletes the given datasource

DeleteDataSource Definition
Input Argument | Tango::DEV_STRING | datasource name
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command SetComponentDataSources :

Sets component datasources according to given dictionary

SetComponentDataSources Definition
Input Argument | Tango::DEV_STRING | JSON dict {comp1: {tds1: ds1, ...}, ...}
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command SetMandatoryComponents :

Sets the mandatory components

SetMandatoryComponents Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | component names
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command MandatoryComponents :

Returns the mandatory components

MandatoryComponents Definition
Input Argument | Tango::DEV_VOID |
Output Argument | Tango::DEVVAR_STRINGARRAY | component names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command UnsetMandatoryComponents :

Removes the given components from the mandatory components

UnsetMandatoryComponents Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of component names
Output Argument | Tango::DEV_VOID |
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command ComponentDataSources :

Returns a list of datasource names for a given component

ComponentDataSources Definition
Input Argument | Tango::DEV_STRING | component name
Output Argument | Tango::DEVVAR_STRINGARRAY | list of datasource names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command ComponentsDataSources :

Returns a list of datasource names for a given components

ComponentsDataSources Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of datasource names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command ComponentsVariables :

Returns a list of variable names for a given components

ComponentsVariables Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of variable names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command ComponentVariables :

Returns a list of variable names for a given component

ComponentVariables Definition
Input Argument | Tango::DEV_STRING | component name
Output Argument | Tango::DEVVAR_STRINGARRAY | list of variable names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command Merge :

Merges give components

Merge Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of component names
Output Argument | Tango::DEV_STRING | merged components
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command DependentComponents :

Returns a list of dependent component names for a given components

DependentComponents Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | component names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of component names
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

Command InstantiatedDataSources :

Returns a list of required datasources

InstantiatedDataSources Definition
Input Argument | Tango::DEVVAR_STRINGARRAY | list of datasources names
Output Argument | Tango::DEVVAR_STRINGARRAY | list of instantiated datasources
DisplayLevel | OPERATOR | ..
Inherited | false | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command NOT allowed for | ON RUNNING | ..

NXSConfigServer Class Attributes
Name | Inherited | Abstract | Attr. type | R/W type | Data type | Level | Description
XMLString | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | It allows to pass XML strings into database during performing StoreComponent and StoreDataSource Moreover, after performing CreateConfiguration it contains the resulting XML configuration.
Selection | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | "It allows to pass JSON strings into database during performing StoreSelection.
JSONSettings | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | "The JSON string with parameters of MySQLdb.connect(...).
Version | false | false | Scalar | READ | Tango::DEV_STRING | OPERATOR | Configuration version
Variables | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | The JSON string with XML configuration variables
STEPDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to be switched into STEP mode during creating configuration process
LinkDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to which links will be added
CanFailDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to be switched into CanFail mode during creating configuration process
ExtraLinkDataSources | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | JSON list of datasources to which links will be added
MergedXML | false | false | Scalar | READ | Tango::DEV_STRING | EXPERT | XML for merged components without applied variables

There is no dynamic attribute defined.

Attribute XMLString :

It allows to pass XML strings into database during performing StoreComponent and StoreDataSource
Moreover, after performing CreateConfiguration it contains the resulting XML configuration.

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | EXPERT
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read NOT allowed for | ON RUNNING
Write NOT allowed for | ON RUNNING
Attribute Properties
label | XML Configuration
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute Selection :

"It allows to pass JSON strings into database during performing StoreSelection.

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | EXPERT
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read NOT allowed for | ON RUNNING
Write NOT allowed for | ON RUNNING
Attribute Properties
label | Selected Component
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute JSONSettings :

"The JSON string with parameters of MySQLdb.connect(...).

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | EXPERT
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | Not set
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | Arguments of MySQLdb.connect(...)
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute Version :

Configuration version

Attribute Definition
Attribute Type | Scalar
R/W Type | READ
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Attribute Properties
label | Configuration Version
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute Variables :

The JSON string with XML configuration variables

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read NOT allowed for | RUNNING
Write NOT allowed for | RUNNING
Attribute Properties
label | XML Configuration Variables
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute STEPDataSources :

JSON list of datasources to be switched into STEP mode during creating configuration process

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | Datasources to be switched into STEP Mode
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute LinkDataSources :

JSON list of datasources to which links will be added

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | Datasources to which links will be added
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute CanFailDataSources :

JSON list of datasources to be switched into CanFail mode during creating configuration process

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | Datasources to be switched into CanFail mode
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute ExtraLinkDataSources :

JSON list of datasources to which links will be added

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | Datasources to which extra links will be added
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute MergedXML :

XML for merged components without applied variables

Attribute Definition
Attribute Type | Scalar
R/W Type | READ
Data Type | Tango::DEV_STRING
Display Level | EXPERT
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read NOT allowed for | ON RUNNING
Attribute Properties
label | XML for merged components
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

NXSConfigServer Class States
Name | Description
ON | Server is ON
OPEN | Open connection to the database
RUNNING | Performing a query